==> javax.print-1.0.3.jar: javax/print/attribute/standard/MediaSize$JIS.clj <==
(ns javax.print.attribute.standard.MediaSize$JIS
  "Class MediaSize.JIS includes MediaSize values for JIS
  (Japanese) media.      *"
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.print.attribute.standard MediaSize$JIS]))

(def *-b-0
  "Static Constant.

  Specifies the JIS B0 size, 1030 mm by 1456 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B0)

(def *-b-1
  "Static Constant.

  Specifies the JIS B1 size, 728 mm by 1030 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B1)

(def *-b-2
  "Static Constant.

  Specifies the JIS B2 size, 515 mm by 728 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B2)

(def *-b-3
  "Static Constant.

  Specifies the JIS B3 size, 364 mm by 515 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B3)

(def *-b-4
  "Static Constant.

  Specifies the JIS B4 size, 257 mm by 364 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B4)

(def *-b-5
  "Static Constant.

  Specifies the JIS B5 size, 182 mm by 257 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B5)

(def *-b-6
  "Static Constant.

  Specifies the JIS B6 size, 128 mm by 182 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B6)

(def *-b-7
  "Static Constant.

  Specifies the JIS B7 size, 91 mm by 128 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B7)

(def *-b-8
  "Static Constant.

  Specifies the JIS B8 size, 64 mm by 91 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B8)

(def *-b-9
  "Static Constant.

  Specifies the JIS B9 size, 45 mm by 64 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B9)

(def *-b-10
  "Static Constant.

  Specifies the JIS B10 size, 32 mm by 45 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B10)

(def *-chou-1
  "Static Constant.

  Specifies the JIS Chou (`long`) #1 envelope size, 142 mm by 332 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_1)

(def *-chou-2
  "Static Constant.

  Specifies the JIS Chou (`long`) #2 envelope size, 119 mm by 277 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_2)

(def *-chou-3
  "Static Constant.

  Specifies the JIS Chou (`long`) #3 envelope size, 120 mm by 235 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_3)

(def *-chou-4
  "Static Constant.

  Specifies the JIS Chou (`long`) #4 envelope size, 90 mm by 205 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_4)

(def *-chou-30
  "Static Constant.

  Specifies the JIS Chou (`long`) #30 envelope size, 92 mm by 235 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_30)

(def *-chou-40
  "Static Constant.

  Specifies the JIS Chou (`long`) #40 envelope size, 90 mm by 225 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_40)

(def *-kaku-0
  "Static Constant.

  Specifies the JIS Kaku (`square`) #0 envelope size, 287 mm by 382 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_0)

(def *-kaku-1
  "Static Constant.

  Specifies the JIS Kaku (`square`) #1 envelope size, 270 mm by 382 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_1)

(def *-kaku-2
  "Static Constant.

  Specifies the JIS Kaku (`square`) #2 envelope size, 240 mm by 332 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_2)

(def *-kaku-3
  "Static Constant.

  Specifies the JIS Kaku (`square`) #3 envelope size, 216 mm by 277 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_3)

(def *-kaku-4
  "Static Constant.

  Specifies the JIS Kaku (`square`) #4 envelope size, 197 mm by 267 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_4)

(def *-kaku-5
  "Static Constant.

  Specifies the JIS Kaku (`square`) #5 envelope size, 190 mm by 240 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_5)

(def *-kaku-6
  "Static Constant.

  Specifies the JIS Kaku (`square`) #6 envelope size, 162 mm by 229 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_6)

(def *-kaku-7
  "Static Constant.

  Specifies the JIS Kaku (`square`) #7 envelope size, 142 mm by 205 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_7)

(def *-kaku-8
  "Static Constant.

  Specifies the JIS Kaku (`square`) #8 envelope size, 119 mm by 197 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_8)

(def *-kaku-20
  "Static Constant.

  Specifies the JIS Kaku (`square`) #20 envelope size, 229 mm by 324 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_20)

(def *-kaku-a-4
  "Static Constant.

  Specifies the JIS Kaku (`square`) A4 envelope size, 228 mm by 312 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_A4)

(def *-you-1
  "Static Constant.

  Specifies the JIS You (`Western`) #1 envelope size, 120 mm by 176 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_1)

(def *-you-2
  "Static Constant.

  Specifies the JIS You (`Western`) #2 envelope size, 114 mm by 162 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_2)

(def *-you-3
  "Static Constant.

  Specifies the JIS You (`Western`) #3 envelope size, 98 mm by 148 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_3)

(def *-you-4
  "Static Constant.

  Specifies the JIS You (`Western`) #4 envelope size, 105 mm by 235 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_4)

(def *-you-5
  "Static Constant.

  Specifies the JIS You (`Western`) #5 envelope size, 95 mm by 217 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_5)

(def *-you-6
  "Static Constant.

  Specifies the JIS You (`Western`) #6 envelope size, 98 mm by 190 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_6)

(def *-you-7
  "Static Constant.

  Specifies the JIS You (`Western`) #7 envelope size, 92 mm by 165 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_7)

==> javax.print-1.0.5.jar: javax/print/attribute/standard/MediaSize$JIS.clj <==
(ns javax.print.attribute.standard.MediaSize$JIS
  "Class MediaSize.JIS includes MediaSize values for JIS
  (Japanese) media.      *"
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.print.attribute.standard MediaSize$JIS]))

(def *-b-0
  "Static Constant.

  Specifies the JIS B0 size, 1030 mm by 1456 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B0)

(def *-b-1
  "Static Constant.

  Specifies the JIS B1 size, 728 mm by 1030 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B1)

(def *-b-2
  "Static Constant.

  Specifies the JIS B2 size, 515 mm by 728 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B2)

(def *-b-3
  "Static Constant.

  Specifies the JIS B3 size, 364 mm by 515 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B3)

(def *-b-4
  "Static Constant.

  Specifies the JIS B4 size, 257 mm by 364 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B4)

(def *-b-5
  "Static Constant.

  Specifies the JIS B5 size, 182 mm by 257 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B5)

(def *-b-6
  "Static Constant.

  Specifies the JIS B6 size, 128 mm by 182 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B6)

(def *-b-7
  "Static Constant.

  Specifies the JIS B7 size, 91 mm by 128 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B7)

(def *-b-8
  "Static Constant.

  Specifies the JIS B8 size, 64 mm by 91 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B8)

(def *-b-9
  "Static Constant.

  Specifies the JIS B9 size, 45 mm by 64 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B9)

(def *-b-10
  "Static Constant.

  Specifies the JIS B10 size, 32 mm by 45 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/B10)

(def *-chou-1
  "Static Constant.

  Specifies the JIS Chou (\"long\") #1 envelope size, 142 mm by 332 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_1)

(def *-chou-2
  "Static Constant.

  Specifies the JIS Chou (\"long\") #2 envelope size, 119 mm by 277 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_2)

(def *-chou-3
  "Static Constant.

  Specifies the JIS Chou (\"long\") #3 envelope size, 120 mm by 235 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_3)

(def *-chou-4
  "Static Constant.

  Specifies the JIS Chou (\"long\") #4 envelope size, 90 mm by 205 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_4)

(def *-chou-30
  "Static Constant.

  Specifies the JIS Chou (\"long\") #30 envelope size, 92 mm by 235 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_30)

(def *-chou-40
  "Static Constant.

  Specifies the JIS Chou (\"long\") #40 envelope size, 90 mm by 225 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/CHOU_40)

(def *-kaku-0
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #0 envelope size, 287 mm by 382 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_0)

(def *-kaku-1
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #1 envelope size, 270 mm by 382 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_1)

(def *-kaku-2
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #2 envelope size, 240 mm by 332 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_2)

(def *-kaku-3
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #3 envelope size, 216 mm by 277 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_3)

(def *-kaku-4
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #4 envelope size, 197 mm by 267 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_4)

(def *-kaku-5
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #5 envelope size, 190 mm by 240 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_5)

(def *-kaku-6
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #6 envelope size, 162 mm by 229 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_6)

(def *-kaku-7
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #7 envelope size, 142 mm by 205 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_7)

(def *-kaku-8
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #8 envelope size, 119 mm by 197 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_8)

(def *-kaku-20
  "Static Constant.

  Specifies the JIS Kaku (\"square\") #20 envelope size, 229 mm by 324 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_20)

(def *-kaku-a-4
  "Static Constant.

  Specifies the JIS Kaku (\"square\") A4 envelope size, 228 mm by 312 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/KAKU_A4)

(def *-you-1
  "Static Constant.

  Specifies the JIS You (\"Western\") #1 envelope size, 120 mm by 176 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_1)

(def *-you-2
  "Static Constant.

  Specifies the JIS You (\"Western\") #2 envelope size, 114 mm by 162 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_2)

(def *-you-3
  "Static Constant.

  Specifies the JIS You (\"Western\") #3 envelope size, 98 mm by 148 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_3)

(def *-you-4
  "Static Constant.

  Specifies the JIS You (\"Western\") #4 envelope size, 105 mm by 235 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_4)

(def *-you-5
  "Static Constant.

  Specifies the JIS You (\"Western\") #5 envelope size, 95 mm by 217 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_5)

(def *-you-6
  "Static Constant.

  Specifies the JIS You (\"Western\") #6 envelope size, 98 mm by 190 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_6)

(def *-you-7
  "Static Constant.

  Specifies the JIS You (\"Western\") #7 envelope size, 92 mm by 165 mm.

  type: javax.print.attribute.standard.MediaSize"
  MediaSize$JIS/YOU_7)
